#!/usr/bin/env python

import sys
from qt import *

class TabDialog( QTabDialog ):
    def __init__( self, parent=None, name=None, filename=None ):
        QTabDialog.__init__( self, parent, name )
        self.filename = QString( filename )
        self.fileinfo = QFileInfo( filename )
        self.setupTab1()
        self.setupTab2()
        self.connect( self, SIGNAL("applyButtonPressed()"), qApp, SLOT("quit()" ) )

    def setupTab1( self ):
        tab1 = QVBox( self )
        tab1.setMargin( 5 )

        QLabel( "Url:", tab1 )
        url = QLabel( '', tab1 )
        url.setFrameStyle( QFrame.Panel | QFrame.Sunken )

        QLabel( "Action:", tab1 )
        path = QLabel( self.fileinfo.dirPath( True ), tab1 )
        path.setFrameStyle( QFrame.Panel | QFrame.Sunken )

        QLabel( "Filename:", tab1 )
        size = QLabel( QString( "%1 KB" ).arg( self.fileinfo.size() ), tab1 )
        size.setFrameStyle( QFrame.Panel | QFrame.Sunken )

        QLabel( "Last Read:", tab1 )
        lread = QLabel( self.fileinfo.lastRead().toString(), tab1 )
        lread.setFrameStyle( QFrame.Panel | QFrame.Sunken )

        self.addTab( tab1, "General" )
   
    def setupTab2( self ):
        tab2 = QVBox( self )
        tab2.setMargin( 5 )

        bg = QButtonGroup( 1, QGroupBox.Horizontal, "Permissions", tab2 )

        readable = QCheckBox( "Readable", bg )
        if self.fileinfo.isReadable() :
            readable.setChecked( True )

        writable = QCheckBox( "Writeable", bg )
        if self.fileinfo.isWritable() :
            writable.setChecked( True )

        executable = QCheckBox( "Executable", bg )
        if self.fileinfo.isExecutable() :
            executable.setChecked( True )

        bg2 = QButtonGroup( 2, QGroupBox.Horizontal, "Owner", tab2 )

        QLabel( "Owner", bg2 )
        owner = QLabel( self.fileinfo.owner(), bg2 )
        owner.setFrameStyle( QFrame.Panel | QFrame.Sunken )

        QLabel( "Group", bg2 )
        group = QLabel( self.fileinfo.group(), bg2 )
        group.setFrameStyle( QFrame.Panel | QFrame.Sunken )

        self.addTab( tab2, "Config" )
    
def main( args ):
    a = QApplication(sys.argv)
    if len(sys.argv) < 2:
        filename = QString(".")
    else:
        filename = QString(sys.argv[1])
            
    tabdialog = TabDialog( None, "pmp_server", filename )
    tabdialog.resize( 400, 300 );
    tabdialog.setCaption( "PMP Server" )
    a.setMainWidget( tabdialog )
    tabdialog.show()
    a.exec_loop()
    
if __name__=="__main__":
    main(sys.argv)
